====================
bisos.common Library
====================

.. contents::
   :depth: 3
..

Overview
========

Common BISOS (ByStar Internet Services OS) Library contains general
purpose modules which build on UnISOS sub-layer capabilities.

Support
=======

| For support, criticism, comments and questions; please contact the
  author/maintainer
| `Mohsen Banan <http://mohsen.1.banan.byname.net>`__ at:
  http://mohsen.1.banan.byname.net/contact

Documentation
=============

Part of ByStar Digital Ecosystem http://www.by-star.net.

This module’s primary documentation is in
http://www.by-star.net/PLPC/180047

Example Usage
=============

::

   from  bisos.common import bxpBaseDir
